@@ -12,6 +12,8 @@
 #include <KActivities/Controller>
 #include <memory>
 
+#include <QScopedPointer>
+
 class ResultWatcherTest : public Test
 {
     Q_OBJECT
@@ -22,6 +24,7 @@ private Q_SLOTS:
     void initTestCase();
 
     void testLinkedResources();
+    void testUsedResources();
 
     void cleanupTestCase();
 };
